/**************************************************************************************************|
|* Copyright 2020 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17p60bsfr.h>
#include <CLK.h>
#include <GPIO.h>
/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function: CLK_HAOOpen                                                                           |
|                                                                                                  |
|  Parameters:                                                                                     |
|         haom -    [in] HAOM_4915KHZ / HAOM_9830KHZ                                               |
|         dhsck   - [in] DHS_HSCKDIV8 / DHS_HSCKDIV4 / DHS_HSCKDIV2 / DHS_HSCKDIV1                 |
|         cpuck  - [in] CPUS_DHSCK / CPUS_HSCK                                                     |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to enable HAO and open the CPU clock setting                       |     
|-------------------------------------------------------------------------------------------------*/
void CLK_HAOOpen(unsigned char haom,				//HAO Frequence Selection
                 unsigned char dhsck,			    //Prescaler of DHS_CK                                          
                 unsigned char cpuck)               //CPU_CK Source Selection 
{
    CLK_HAOSelect(haom);         
    CLK_HAOEnable();               
    CLK_OSCSelect(OSCS_HAO) ;        
    CLK_DHSCKSelect(dhsck);      
    CLK_CPUCKSelect(cpuck);     

}

/*-------------------------------------------------------------------------------------------------|
|  Function: CLK_XTOpen                                                                  |
|                                                                                                  |
|  Parameters:                                                                                     |
|         xts -    [in] XTS_32768 / XTS_2M / XTS_16M                                               |
|         dhsck   - [in] DHS_HSCKDIV8 / DHS_HSCKDIV4 / DHS_HSCKDIV2	/ DHS_HSCKDIV1                 |
|         cpuck  - [in] CPUS_DHSCK / CPUS_HSCK                                                     |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to enable XT and open the CPU clock setting                        |
|-------------------------------------------------------------------------------------------------*/
void CLK_XTOpen(unsigned char xts,				//XTI Frequence Selection
                unsigned char dhsck,			//Prescaler of DHS_CK                                          
                unsigned char cpuck)            //CPU_CK Source Selection 
{
    GPIO_PT2InputMode(0);  // config PT2.0/PT2.1 as Input Mode
    GPIO_PT2InputMode(1);
    GPIO_PT2CLRPU(0);      // Disable Input pull up in case of Input Mode
    GPIO_PT2CLRPU(1);
    CLK_XTSelect(xts); 
    CLK_XTEnable();
    CLK_OSCSelect(OSCS_XT);
    CLK_HAODisable();    
    CLK_DHSCKSelect(dhsck);      
    CLK_CPUCKSelect(cpuck);    
}

/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
