/**************************************************************************************************|
|* Copyright 2020 Hycon Technology, Corp.                                                     *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY17P6X Series                                                                 *|
|**************************************************************************************************/

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for CMP

// MFCCN0 //
#define CPRH                    6
#define CPRH_MSK               (3 << CPRH) 
#define CPRH_VLCD              (3 << CPRH)
#define CPRH_VDDA              (2 << CPRH)
#define CPRH_VDD               (1 << CPRH)
#define CPRH_DISABLE           (0 << CPRH)

#define MFCO                     5
#define MFCO_MSK                (1 << MFCO)
#define MFCO_PGN                (1 << MFCO)
#define MFCO_NGP                (0 << MFCO)
  
#define CPIS                     4
#define CPIS_MSK                (1 << CPIS)
#define CPIS_CLOSED             (1 << CPIS)
#define CPIS_OPEN               (0 << CPIS)

#define CPOR                     3
#define CPOR_MSK                (1 << CPOR)
#define CPOR_INVERSE            (1 << CPOR)
#define CPOR_NORMAL             (0 << CPOR)

#define CPDF                     2
#define CPDF_MSK                (1 << CPDF)
#define CPDF_ENABLE             (1 << CPDF)
#define CPDF_DISABLE            (0 << CPDF)

#define CMPHS                    1
#define CMPHS_MSK               (1 << CMPHS)
#define CMPHS_NORMAL            (1 << CMPHS)
#define CMPHS_LOWPOWER          (0 << CMPHS)

#define ENMFC                    0
#define ENMFC_MSK               (1 << ENMFC)
#define ENMFC_ENABLE            (1 << ENMFC)
#define ENMFC_DISABLE           (0 << ENMFC)

// MFCCN1 //
#define CPRL2                     7
#define CPRL2_MSK               (1 << CPRL2)
#define CPRL2_AGND              (1 << CPRL2)
#define CPRL2_VSS               (0 << CPRL2)

#define CPRL1                     6
#define CPRL1_MSK                (1 << CPRL1)
#define CPRL1_SHORT              (1 << CPRL1)
#define CPRL1_OPEN               (0 << CPRL1)

#define CPRL0                     5
#define CPRL0_MSK                (1 << CPRL0)
#define CPRL0_SHORT              (1 << CPRL0)
#define CPRL0_OPEN               (0 << CPRL0)

#define CPPS                     2
#define CPPS_MSK                (3 << CPPS) 
#define CPPS_1V2                (3 << CPPS)
#define CPPS_PB3                (2 << CPPS)
#define CPPS_PB0                (1 << CPPS)
#define CPPS_LVDIN              (0 << CPPS)

#define CPNS                     0
#define CPNS_MSK                (3 << CPNS) 
#define CPNS_RLO                (3 << CPNS)
#define CPNS_PB3                (2 << CPNS)
#define CPNS_PB0                (1 << CPNS)
#define CPNS_LVDIN              (0 << CPNS)

// MFCCN2 //
#define CPDA                     0
#define CPDA_MSK                (31 << CPDA)
#define CPDA_31DIV32            (31 << CPDA) 
#define CPDA_30DIV32            (30 << CPDA)
#define CPDA_29DIV32            (29 << CPDA)
#define CPDA_28DIV32            (28 << CPDA)
#define CPDA_27DIV32            (27 << CPDA)
#define CPDA_26DIV32            (26 << CPDA)
#define CPDA_25DIV32            (25 << CPDA)
#define CPDA_24DIV32            (24 << CPDA)
#define CPDA_23DIV32            (23 << CPDA)
#define CPDA_22DIV32            (22 << CPDA)
#define CPDA_21DIV32            (21 << CPDA)
#define CPDA_20DIV32            (20 << CPDA)
#define CPDA_19DIV32            (19 << CPDA)
#define CPDA_18DIV32            (18 << CPDA)
#define CPDA_17DIV32            (17 << CPDA)
#define CPDA_16DIV32            (16 << CPDA)
#define CPDA_15DIV32            (15 << CPDA)
#define CPDA_14DIV32            (14 << CPDA)
#define CPDA_13DIV32            (13 << CPDA)
#define CPDA_12DIV32            (12 << CPDA)
#define CPDA_11DIV32            (11 << CPDA)
#define CPDA_10DIV32            (10 << CPDA)
#define CPDA_9DIV32             (9 << CPDA)
#define CPDA_8DIV32             (8 << CPDA)
#define CPDA_7DIV32             (7 << CPDA)
#define CPDA_6DIV32             (6 << CPDA)
#define CPDA_5DIV32             (5 << CPDA)
#define CPDA_4DIV32             (4 << CPDA)
#define CPDA_3DIV32             (3 << CPDA)
#define CPDA_2DIV32             (2 << CPDA)
#define CPDA_1DIV32             (1 << CPDA)
#define CPDA_0                  (0 << CPDA)

// MFCCN3 //
#define CPDM4                    4
#define CPDM4_MSK               (1 << CPDM4)
#define CPDM4_ENABLE            (1 << CPDM4)
#define CPDM4_DISABLE           (0 << CPDM4)

#define CPDM3                    3
#define CPDM3_MSK               (1 << CPDM3)
#define CPDM3_ENABLE            (1 << CPDM3)
#define CPDM3_DISABLE           (0 << CPDM3)

#define CPDM2                    2
#define CPDM2_MSK               (1 << CPDM2)
#define CPDM2_ENABLE            (1 << CPDM2)
#define CPDM2_DISABLE           (0 << CPDM2)

#define CPDM1                    1
#define CPDM1_MSK               (1 << CPDM1)
#define CPDM1_ENABLE            (1 << CPDM1)
#define CPDM1_DISABLE           (0 << CPDM1)

#define CPDM0                    0
#define CPDM0_MSK               (1 << CPDM0)
#define CPDM0_ENABLE            (1 << CPDM0)
#define CPDM0_DISABLE           (0 << CPDM0)

#define CPDM_DISABLE    0xe0


/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define MFC_Enable()			     (MCCN0 |= ENCMP_ENABLE)
#define MFC_Disable()			     (MCCN0 &= (~ENCMP_MSK))
#define MFC_InShort(Sel)		    	(MCCN0 = ((MCCN0 & (~CPIS_MSK)) | Sel))
#define MFC_OutInverse(Sel)          (MCCN0 = ((MCCN0 & (~CPOR_MSK)) | Sel))
#define MFC_OutputReverse()			(MCCN0 |= CPOR_INVERSE)
#define MFC_OutputNormal()			(MCCN0 &= (~CPOR_MSK))
#define MFC_MODESel(Sel)           (MCCN0 = ((MCCN0 & (~CMPHS_MSK)) | Sel))
#define MFC_NormlMode()			  (MCCN0 |= CMPHS_NORMAL)
#define MFC_LowPowerMode()			  (MCCN0 &= (~CMPHS_MSK))
#define MFC_2usLPFEnable()			(MCCN0 |= CPDF_ENABLE)
#define MFC_2usLPFDisable()			(MCCN0 &= (~CPDF_MSK))
#define	MFC_OutputSelect(sel)			(MCCN0 = ((MCCN0 & (~ENRCC_MSK)) | sel))

#define MFC_CMPResult()                  (MCCN0 & CMPO_MSK)
#define MFC_CMPOIsPGN()					(MCCN0 & CMPO_PGN)
#define MFC_CMPOIsNGP()					(~(MCCN0 | CMPO_NGP))
#define MFC_CPRLShort()					(MCCN1 |= CPRL_SHORT)
#define MFC_CPRLOpen()					(MCCN1 &= (~CPRL_MSK))
#define MFC_RLO_VrefSel(sel)			(MCCN1 = ((MCCN1 & (~CPRH_MSK)) | sel))
#define MFC_PInput(sel)						(MCCN1 = ((MCCN1 & (~CPPS_MSK)) | sel))
#define MFC_NInput(sel)						(MCCN1 = ((MCCN1 & (~CPNS_MSK)) | sel))

#define MFC_R_DASel(Sel)				(MCCN2 = ((MCCN2 & (~CPDA_MSK)) | Sel))

#define MFC_CPDM4Enable()				(MCCN3 |= CPDM4_ENABLE)
#define MFC_CPDM4Disable()				(MCCN3 &= (~CPDM4_MSK))
#define MFC_CPDM3Enable()				(MCCN3 |= CPDM3_ENABLE)
#define MFC_CPDM3Disable()				(MCCN3 &= (~CPDM3_MSK))
#define MFC_CPDM2Enable()				(MCCN3 |= CPDM2_ENABLE)
#define MFC_CPDM2Disable()				(MCCN3 &= (~CPDM2_MSK))
#define MFC_CPDM1Enable()				(MCCN3 |= CPDM1_ENABLE)
#define MFC_CPDM1Disable()				(MCCN3 &= (~CPDM1_MSK))
#define MFC_CPDM0Enable()				(MCCN3 |= CPDM0_ENABLE)
#define MFC_CPDM0Disable()				(MCCN3 &= (~CPDM0_MSK))
#define MFC_CPDMSet(cpdm)               (MCCN3 |= (1 << cpdm))
#define MFC_CPDMCLR(cpdm)               (MCCN3 &= ~(1 << cpdm))
#define	MFC_CPDMALLCLR()				(MCCN3 &= 0xe0)


#define MFC_INT_Enable()              (INTE2 |= MFCIE_ENABLE)
#define MFC_INT_Disable()             (INTE2 &= (~MFCIE_MSK))
#define MFC_INT_IsFlag()              (INTF2 & MFCIF_SET)
#define MFC_INT_ClearFlag()           (INTF2 &= (~MFCIF_MSK))
//#define MFCIE_Enable()             (INTE2 |= MFCIE_ENABLE)
//#define MFCIE_Disable()            (INTE2 &= (~MFCIE_MSK))
//#define MFCIF_IsFlag()             (INTF2 & MFCIF_SET)
//#define MFCIF_ClearFlag()          (INTF2 &= (~MFCIF_MSK))

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void MFC_Open( unsigned char cpps,   //CMP P Input select
           					 unsigned char cpns,   //CMP N Input select
              				 unsigned char cmphs, //CMP Work mode select
              				 unsigned char cpor,     //CMP Output reverse control
              				 unsigned char enrcc);   //CMP Output control
void MFC_RLOSet( unsigned char cprh,   //CMP RLO reference voltage source selection
           					    unsigned char cprl,   //CMP RLO  resistor(22.5R/20R) short control
              				    unsigned char cpda,   //CMP RLO  reference voltage division control
              			   	    unsigned char cpdm);  //CMP hysteresis control 
