/**************************************************************************************************|
|* Copyright 2020 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY17P6X Series                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// PWRCN2 //
#define ENFIR                      3
#define ENFIR_MSK                 (1 << ENFIR)
#define ENFIR_ENABLE              (1 << ENFIR)
#define ENFIR_DISABLE             (0 << ENFIR)

//// RMSCN // 
#define ENRMS                     7
#define ENRMS_MSK                (1 << ENRMS)
#define ENRMS_ENABLE             (1 << ENRMS)
#define ENRMS_DISABLE            (0 << ENRMS)

#define ENLPF                       6
#define ENLPF_MSK                   (1 << ENLPF)
#define ENLPF_ENABLE                (1 << ENLPF)
#define ENLPF_DISABLE               (0 << ENLPF)

#define ENSQRE                       5
#define ENSQRE_MSK                   (1 << ENSQRE)
#define ENSQRE_SQUARE                (1 << ENSQRE)
#define ENSQRE_ABSOLUTE             (0 << ENSQRE)

#define LPFBW                      3
#define LPFBW_MSK           (3 << LPFBW)
#define LPFBW_2048           (3 << LPFBW)
#define LPFBW_1024           (2 << LPFBW)
#define LPFBW_512             (1 << LPFBW)
#define LPFBW_256             (0 << LPFBW)

#define ENPKH                      2
#define ENPKH_MSK                 (1 << ENPKH)
#define ENPKH_ENABLE              (1 << ENPKH)
#define ENPKH_DISABLE             (0 << ENPKH)

#define RSLPF                      1
#define RSLPF_MSK                 (1 << RSLPF)
#define RSLPF_ENABLE              (1 << RSLPF)
#define RSLPF_DISABLE             (0 << RSLPF)

#define RSRMS                      0
#define RSRMS_MSK                 (1 << RSRMS)
#define RSRMS_ENABLE              (1 << RSRMS)
#define RSRMS_DISABLE             (0 << RSRMS)

/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define DSP_FIREnable()                 (PWRCN2 |= ENFIR_ENABLE)
#define DSP_FIRDisable()                (PWRCN2 &= (~ENFIR_MSK))

#define DSP_RMSEnable()                 (RMSCN |= ENRMS_ENABLE)
#define DSP_RMSDisable()                (RMSCN &= (~ENRMS_MSK))
#define DSP_LPFEnable()                 (RMSCN |= ENLPF_ENABLE)
#define DSP_LPFDisable()                (RMSCN &= (~ENLPF_MSK))
#define DSP_RMSData(dat)              (RMSCN = ((RMSCN & (~ENSQRE_MSK)) | dat))
#define DSP_LPFOSR(osr)              (RMSCN = ((RMSCN & (~LPFBW_MSK)) | osr))
#define DSP_PeakHoldEnable()                 (RMSCN |= ENPKH_ENABLE)
#define DSP_PeakHoldDisable()                (RMSCN &= (~ENPKH_MSK))
#define DSP_LPFReset()                 (RMSCN |= RSLPF_ENABLE)
#define DSP_RSLPFDisable()                (RMSCN &= (~RSLPF_MSK))
#define DSP_RMSReset()                 (RMSCN |= RSRMS_ENABLE)
#define DSP_RSRMSDisable()                (RMSCN &= (~RSRMS_MSK))

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/

