/**************************************************************************************************|
|* Copyright 2019 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17p60bsfr.h>
#include <MFC.h>
#include <INT.h>

/*-----------------------------------------------------------------------------------------------------|
|  Function: MFC_Open                                                                                     |
|                                                                                                                         |
|  Parameters:                                                                                                    |
|         cpps        - [in] CPPS_1V2 / CPPS_PB3 / CPPS_PB0 / CPPS_LVDIN        |
|         cpns         - [in] CPNS_RLO / CPNS_PB3 / CPNS_PB0 / CPNS_LVDIN      |
|         cmphs      - [in] CMPHS_NORMAL/ CMPHS_LOWPOWER                       |
|         cpor         - [in] CPOR_INVERSE / CPOR_NORMAL                                |
|                                                                                                                          | 
|  Returns:                                                                                                          |
|         None                                                                                                        |
|                                                                                                                          |
|  Description:                                                                                                      |
|         This function is used to open the MFC								                        |
|------------------------------------------------------------------------------------------------------*/
void MFC_Open( unsigned char cpps,   //MFC P Input select
           					 unsigned char cpns,   //MFC N Input select
              				 unsigned char cmphs, //MFC Work mode select
              				 unsigned char cpor)     //MFC Output reverse control
{
	MFC_PInput(cpps);             //select positive input channel
	MFC_NInput(cpns);             //select negative input channel
	MFC_WorkMode(cmphs);   //select MFC work mode
	MFC_Outputphase(cpor);	 //select MFC output phase
	
	MFCIE_Enable();
	MFCIF_ClearFlag();
	MFC_Enable();
}

/*-----------------------------------------------------------------------------------------------------|
|  Function: MFC_RLOSet                                                                                     |
|                                                                                                                         |
|  Parameters:                                                                                                    |
|         cprh        - [in] CPRH_VLCD / CPRH_VDDA / CPRH_VDD / CPPS_1V2        |
|         cprl2       - [in] CPNS_CH0 / CPNS_CH1 / CPNS_CH2 / CPNS_RLO      |
|         cprl1       - [in] CMPHS_NORMAL/ CMPHS_LOWPOWER                       |
|         cprl1       - [in] CPOR_REVERSE / CPOR_NORMAL                                |
|         cpda        - [in] ENRCC_DISABLE / ENRCC_RX                                      |
|                                  ENRCC_PT16 / ENRCC_RESERVED                              |
|                                                                                                                          | 
|  Returns:                                                                                                          |
|         None                                                                                                        |
|                                                                                                                          |
|  Description:                                                                                                      |
|         This function is used to setting the RLO config	                                      |
|------------------------------------------------------------------------------------------------------*/
void MFC_RLOSet( unsigned char cprh,   //VR voltage source
           		                unsigned char cprl2,   //VR ground
              	                unsigned char cprl1,   //22.5R control
                                unsigned char cprl0,   //20R control
              	               unsigned char cpda)   //CMP Output control
{
    MFC_RLOVoltage(cprh);
    MFC_RLOGround(cprl2);
    MFC_22R5Control(cprl1);
    MFC_20RControl(cprl0);
    MFC_R_DASel(cpda);
	
}


