/**************************************************************************************************|
|* Copyright 2020 Hycon Technology, Corp.                                                     *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY17P6X Series                                                                 *|
|**************************************************************************************************/

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
#include <INT.h>           // Interrupt Config for CMP

// MFCN0 //
#define CPRH                    6
#define CPRH_MSK               (3 << CPRH) 
#define CPRH_VLCD              (3 << CPRH)
#define CPRH_VDDA              (2 << CPRH)
#define CPRH_VDD               (1 << CPRH)
#define CPRH_DISABLE           (0 << CPRH)

#define MFCO                     5
#define MFCO_MSK                (1 << MFCO)
#define MFCO_PGN                (1 << MFCO)
#define MFCO_NGP                (0 << MFCO)
  
#define CPIS                     4
#define CPIS_MSK                (1 << CPIS)
#define CPIS_CLOSED             (1 << CPIS)
#define CPIS_OPEN               (0 << CPIS)

#define CPOR                     3
#define CPOR_MSK                (1 << CPOR)
#define CPOR_INVERSE            (1 << CPOR)
#define CPOR_NORMAL             (0 << CPOR)

#define CPDF                     2
#define CPDF_MSK                (1 << CPDF)
#define CPDF_ENABLE             (1 << CPDF)
#define CPDF_DISABLE            (0 << CPDF)

#define CMPHS                    1
#define CMPHS_MSK               (1 << CMPHS)
#define CMPHS_NORMAL            (1 << CMPHS)
#define CMPHS_LOWPOWER          (0 << CMPHS)

#define ENMFC                    0
#define ENMFC_MSK               (1 << ENMFC)
#define ENMFC_ENABLE            (1 << ENMFC)
#define ENMFC_DISABLE           (0 << ENMFC)

// MFCN1 //
#define CPRL2                     7
#define CPRL2_MSK               (1 << CPRL2)
#define CPRL2_AGND              (1 << CPRL2)
#define CPRL2_VSS               (0 << CPRL2)

#define CPRL1                     6
#define CPRL1_MSK                (1 << CPRL1)
#define CPRL1_SHORT              (1 << CPRL1)
#define CPRL1_OPEN               (0 << CPRL1)

#define CPRL0                     5
#define CPRL0_MSK                (1 << CPRL0)
#define CPRL0_SHORT              (1 << CPRL0)
#define CPRL0_OPEN               (0 << CPRL0)

#define CPPS                     2
#define CPPS_MSK                (3 << CPPS) 
#define CPPS_1V2                (3 << CPPS)
#define CPPS_PB3                (2 << CPPS)
#define CPPS_PB0                (1 << CPPS)
#define CPPS_LVDIN              (0 << CPPS)

#define CPNS                     0
#define CPNS_MSK                (3 << CPNS) 
#define CPNS_RLO                (3 << CPNS)
#define CPNS_PB3                (2 << CPNS)
#define CPNS_PB0                (1 << CPNS)
#define CPNS_LVDIN              (0 << CPNS)

// MFCN2 //
#define CPDA                     0
#define CPDA_MSK                (31 << CPDA)
#define CPDA_31DIV32            (31 << CPDA) 
#define CPDA_30DIV32            (30 << CPDA)
#define CPDA_29DIV32            (29 << CPDA)
#define CPDA_28DIV32            (28 << CPDA)
#define CPDA_27DIV32            (27 << CPDA)
#define CPDA_26DIV32            (26 << CPDA)
#define CPDA_25DIV32            (25 << CPDA)
#define CPDA_24DIV32            (24 << CPDA)
#define CPDA_23DIV32            (23 << CPDA)
#define CPDA_22DIV32            (22 << CPDA)
#define CPDA_21DIV32            (21 << CPDA)
#define CPDA_20DIV32            (20 << CPDA)
#define CPDA_19DIV32            (19 << CPDA)
#define CPDA_18DIV32            (18 << CPDA)
#define CPDA_17DIV32            (17 << CPDA)
#define CPDA_16DIV32            (16 << CPDA)
#define CPDA_15DIV32            (15 << CPDA)
#define CPDA_14DIV32            (14 << CPDA)
#define CPDA_13DIV32            (13 << CPDA)
#define CPDA_12DIV32            (12 << CPDA)
#define CPDA_11DIV32            (11 << CPDA)
#define CPDA_10DIV32            (10 << CPDA)
#define CPDA_9DIV32             (9 << CPDA)
#define CPDA_8DIV32             (8 << CPDA)
#define CPDA_7DIV32             (7 << CPDA)
#define CPDA_6DIV32             (6 << CPDA)
#define CPDA_5DIV32             (5 << CPDA)
#define CPDA_4DIV32             (4 << CPDA)
#define CPDA_3DIV32             (3 << CPDA)
#define CPDA_2DIV32             (2 << CPDA)
#define CPDA_1DIV32             (1 << CPDA)
#define CPDA_0                  (0 << CPDA)

// MFCN3 //
#define CPDM4                    4
#define CPDM4_MSK               (1 << CPDM4)
#define CPDM4_ENABLE            (1 << CPDM4)
#define CPDM4_DISABLE           (0 << CPDM4)

#define CPDM3                    3
#define CPDM3_MSK               (1 << CPDM3)
#define CPDM3_ENABLE            (1 << CPDM3)
#define CPDM3_DISABLE           (0 << CPDM3)

#define CPDM2                    2
#define CPDM2_MSK               (1 << CPDM2)
#define CPDM2_ENABLE            (1 << CPDM2)
#define CPDM2_DISABLE           (0 << CPDM2)

#define CPDM1                    1
#define CPDM1_MSK               (1 << CPDM1)
#define CPDM1_ENABLE            (1 << CPDM1)
#define CPDM1_DISABLE           (0 << CPDM1)

#define CPDM0                    0
#define CPDM0_MSK               (1 << CPDM0)
#define CPDM0_ENABLE            (1 << CPDM0)
#define CPDM0_DISABLE           (0 << CPDM0)

#define CPDM_DISABLE    0xe0


/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define MFC_Enable()			     (MFCN0 |= ENMFC_ENABLE)
#define MFC_Disable()			     (MFCN0 &= (~ENMFC_MSK))
#define MFC_Outputphase(Sel)        (MFCN0 = ((MFCN0 & (~CPOR_MSK)) | Sel))
#define MFC_OutputReverse()			(MFCN0 |= CPOR_INVERSE)
#define MFC_OutputNphase controlormal()			(MFCN0 &= (~CPOR_MSK))
#define MFC_WorkMode(Sel)           (MFCN0 = ((MFCN0 & (~CMPHS_MSK)) | Sel))
#define MFC_NormlMode()			     (MFCN0 |= CMPHS_NORMAL)
#define MFC_LowPowerMode()		 (MFCN0 &= (~CMPHS_MSK))
#define MFC_2usLPFEnable()			(MFCN0 |= CPDF_ENABLE)
#define MFC_2usLPFDisable()			(MFCN0 &= (~CPDF_MSK))
#define MFC_RLOVoltage(sel)		      (MFCN0 = ((MFCN0 & (~CPRH_MSK)) | sel))
#define MFC_RLOGround(sel)			 (MFCN1 = ((MFCN1 & (~CPRL2_MSK)) | sel))
#define MFC_22R5Control(sel)               (MFCN1 = ((MFCN1 & (~CPRL1_MSK)) | sel))
#define MFC_22R5Short()					(MFCN1 |= CPRL1_SHORT)
#define MFC_22R5Open()				   (MFCN1 &= (~CPRL1_MSK))
#define MFC_20RControl(sel)                (MFCN1 = ((MFCN1 & (~CPRL0_MSK)) | sel))
#define MFC_20RShort()				  	 (MFCN1 |= CPRL0_SHORT)
#define MFC_20ROpen()				    (MFCN1 &= (~CPRL0_MSK))
#define MFC_R_DASel(Sel)			   (MFCN2 = ((MFCN2 & (~CPDA_MSK)) | Sel))


#define MFC_OutputStatus()              (MFCN0 & MFCO_MSK)
#define MFC_OutputIsPGN()			   (MFCN0 & MFCO_PGN)
#define MFC_OutputIsNGP()			   (~(MFCN0 | MFCO_NGP))

#define MFC_PInput(sel)						(MFCN1 = ((MFCN1 & (~CPPS_MSK)) | sel))
#define MFC_NInput(sel)						(MFCN1 = ((MFCN1 & (~CPNS_MSK)) | sel))


#define MFC_CPDM4Enable()				(MFCN3 |= CPDM4_ENABLE)
#define MFC_CPDM4Disable()				(MFCN3 &= (~CPDM4_MSK))
#define MFC_CPDM3Enable()				(MFCN3 |= CPDM3_ENABLE)
#define MFC_CPDM3Disable()				(MFCN3 &= (~CPDM3_MSK))
#define MFC_CPDM2Enable()				(MFCN3 |= CPDM2_ENABLE)
#define MFC_CPDM2Disable()				(MFCN3 &= (~CPDM2_MSK))
#define MFC_CPDM1Enable()				(MFCN3 |= CPDM1_ENABLE)
#define MFC_CPDM1Disable()				(MFCN3 &= (~CPDM1_MSK))
#define MFC_CPDM0Enable()				(MFCN3 |= CPDM0_ENABLE)
#define MFC_CPDM0Disable()				(MFCN3 &= (~CPDM0_MSK))
#define MFC_CPDMSET(cpdm)               (MFCN3 |= (1 << cpdm))
#define MFC_CPDMCLR(cpdm)               (MFCN3 &= ~(1 << cpdm))
#define	MFC_CPDMALLCLR()				(MFCN3 &= CPDM_DISABLE)


#define MFC_INT_Enable()              (INTE2 |= MFCIE_ENABLE)
#define MFC_INT_Disable()             (INTE2 &= (~MFCIE_MSK))
#define MFC_INT_IsFlag()              (INTF2 & MFCIF_SET)
#define MFC_INT_ClearFlag()           (INTF2 &= (~MFCIF_MSK))
//#define MFCIE_Enable()             (INTE2 |= MFCIE_ENABLE)
//#define MFCIE_Disable()            (INTE2 &= (~MFCIE_MSK))
//#define MFCIF_IsFlag()             (INTF2 & MFCIF_SET)
//#define MFCIF_ClearFlag()          (INTF2 &= (~MFCIF_MSK))

/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void MFC_Open( unsigned char cpps,   //MFC P Input select
           					 unsigned char cpns,   //MFC N Input select
              				 unsigned char cmphs, //MFC Work mode select
              				 unsigned char cpor);     //MFC Output reverse control
void MFC_RLOSet( unsigned char cprh,   //VR voltage source
           		                unsigned char cprl2,   //VR ground
              	                unsigned char cprl1,   //22.5R control
                                unsigned char cprl0,   //20R control
              	               unsigned char cpda);   //CMP Output control
