/**************************************************************************************************|
|* Copyright 2020 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|* - Generic Peripheral Library: A general and functional Interface for the specific Peripheral   *|
|* - Low Level Peripheral Access: Register-Bits Level access Macro, user must take care           *|
|*   of calling procedure and hardware constraints                                                *|
|* - Support Target: HY17P6X Series                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*                               Peripheral Register Bits field                                   *|
|**************************************************************************************************/
// PWRCN //
#define ENBGR                      7
#define ENBGR_MSK                 (1 << ENBGR)
#define ENBGR_ENABLE              (1 << ENBGR)
#define ENBGR_DISABLE             (0 << ENBGR)

#define LDOC                       4
#define LDOC_MSK                  (7 << LDOC)
#define LDOC_5V0                  (7 << LDOC)
#define LDOC_4V5                  (6 << LDOC)
#define LDOC_4V0                  (5 << LDOC)
#define LDOC_3V6                  (4 << LDOC)
#define LDOC_3V3                  (3 << LDOC)
#define LDOC_2V9                  (2 << LDOC)
#define LDOC_2V6                  (1 << LDOC)
#define LDOC_2V4                  (0 << LDOC)

#define LDOM                       2
#define LDOM_MSK                  (3 << LDOM)
#define LDOM_BLOUT                (3 << LDOM)
#define LDOM_HIGH                 (2 << LDOM)
#define LDOM_VDD                  (1 << LDOM)
#define LDOM_DISABLE              (0 << LDOM)

#define ENLDO                      1                
#define ENLDO_MSK                 (1 << ENLDO)
#define ENLDO_ENABLE              (1 << ENLDO)
#define ENLDO_DISABLE             (0 << ENLDO)

#define CSFON                      0                
#define CSFON_MSK                 (1 << CSFON)
#define CSFON_ENABLE              (1 << CSFON)
#define CSFON_DISABLE             (0 << CSFON)

//// PWRCN1 // 
#define ENREFO                     7
#define ENREFO_MSK                (1 << ENREFO)
#define ENREFO_ENABLE             (1 << ENREFO)
#define ENREFO_DISABLE            (0 << ENREFO)

#define ENCNTI                       5
#define ENCNTI_MSK                   (1 << ENCNTI)
#define ENCNTI_PCNTI                (1 << ENCNTI)
#define ENCNTI_CMPO               (0 << ENCNTI)

#define ENCTR                       4
#define ENCTR_MSK                   (1 << ENCTR)
#define ENCTR_ENABLE                (1 << ENCTR)
#define ENCTR_DISABLE               (0 << ENCTR)

#define ENVS                       3
#define ENVS_MSK                   (1 << ENVS)
#define ENVS_ENABLE                (1 << ENVS)
#define ENVS_DISABLE               (0 << ENVS)

#define SAGND                      0
#define SAGND_MSK                 (7 << SAGND)
#define SAGND_4DIV10VDDA          (4 << SAGND)
#define SAGND_5DIV10VDDA          (3 << SAGND)
#define SAGND_1DIV10VDDA          (2 << SAGND)
#define SAGND_3DIV10VDDA          (1 << SAGND)
#define SAGND_FLOATING            (0 << SAGND)

//// PWRCN2 //
#define VGGS                       6
#define VGGS_MSK                  (1 << VGGS)
#define VGGS_RESERVE              (1 << VGGS)
#define VGGS_VDD                  (0 << VGGS)

#define LDOPL                      2
#define LDOPL_MSK                 (1 << LDOPL)
#define LDOPL_ENABLE              (1 << LDOPL)
#define LDOPL_DISABLE             (0 << LDOPL)

#define ENTPS                      1
#define ENTPS_MSK                 (1 << ENTPS)
#define ENTPS_ENABLE              (1 << ENTPS)
#define ENTPS_DISABLE             (0 << ENTPS)

//// NET0 //
#define SDIO                      7
#define SDIO_MSK                    (1 << SDIO)
#define SDIO_SHORT               (1 << SDIO)
#define SDIO_OPEN                 (0 << SDIO)

#define SREFO                      6
#define SREFO_MSK                 (1 << SREFO)
#define SREFO_PB4                  (1 << SREFO)
#define SREFO_BGR                 (0 << SREFO)

#define SFT1                       4
#define SFT1_MSK                   (3 << SFT1)
#define SFT1_DISABLE            (3 << SFT1)
#define SFT1_SHORT              (2 << SFT1)
#define SFT1_10K                    (1 << SFT1)
#define SFT1_100K                  (0 << SFT1)

//// NET3 //
#define SCMPO                      4
#define SCMPO_MSK                 (1 << SCMPO)
#define SCMPO_MFCO              (1 << SCMPO)
#define SCMPO_REV                 (0 << SCMPO)

#define CNTIIF                      0
#define CNTIIF_MSK                    (1 << CNTIIF)
#define CNTIIF_PCNTI                 (1 << CNTIIF)
#define CNTIIF_CMPO                 (0 << CNTIIF)
/**************************************************************************************************|
|*                                      Function Level                                            *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function-like Macro:                                                                            |
|    Register Bits field Configuration without function call overhead,                             |
|    user should take care of detail of h/w behavior and constrains.                               |
|-------------------------------------------------------------------------------------------------*/
#define PWR_BGREnable()                 (PWRCN |= ENBGR_ENABLE)
#define PWR_BGRDisable()                (PWRCN &= (~ENBGR_MSK))
#define PWR_LDOEnable()                 (PWRCN |= ENLDO_ENABLE)
#define PWR_LDODisable()                (PWRCN &= (~ENLDO_MSK))
#define PWR_CSFONEnable()               (PWRCN |= CSFON_ENABLE)
#define PWR_CSFONDisable()              (PWRCN &= (~CSFON_MSK))
#define PWR_LDOSel(LDOVSel)             (PWRCN = ((PWRCN & (~LDOC_MSK)) | LDOVSel))
#define PWR_LDOMode(LDOMode)            (PWRCN = ((PWRCN & (~LDOM_MSK)) | LDOMode))

#define PWR_REFOEnable()                     (PWRCN1 |= ENREFO_ENABLE)
#define PWR_REFODisable()                    (PWRCN1 &= (~ENREFO_MSK))
#define PWR_VrefEnable()                        (PWRCN1 |= ENVS_ENABLE)
#define PWR_VrefDisable()                       (PWRCN1 &= (~ENVS_MSK))
#define PWR_AGNDSelect(AGNDSel)      (PWRCN1 = ((PWRCN1 & (~SAGND_MSK)) | AGNDSel))
#define PWR_FreqCountSource(input)      (PWRCN1 = ((PWRCN1 & (~ENCNTI_MSK)) | input))
#define PWR_FreqCountEnable()              (PWRCN1 |= ENCTR_ENABLE)
#define PWR_FreqCountDisable()             (PWRCN1 &= (~ENCTR_MSK))
#define PWR_VGGEnable()                       (PWRCN2 |= VGGS_ENABLE)
#define PWR_VGGDisable()                       (PWRCN2 &= (~VGGS_MSK))
#define PWR_LDOPLEnable()                   (PWRCN2 |= LDOPL_ENABLE)
#define PWR_LDOPLDisable()                   (PWRCN2 &= (~LDOPL_MSK))
#define PWR_ENTPSEnable()                   (PWRCN2 |= ENTPS_ENABLE)
#define PWR_ENTPSDisable()                  (PWRCN2 &= (~ENTPS_MSK))
//#define ADC_ENTPSEnable()                  (PWRCN2 |= ENTPS_ENABLE)
//#define ADC_ENTPSDisable()                  (PWRCN2 &= (~ENTPS_MSK))

#define PWR_REFOSource(REFOSel)         (NET0 = ((NET0 & (~SREFO_MSK)) | REFOSel))
#define PWR_SDIOShort()                 (NET0 |= SDIO_SHORT)
#define PWR_SDIOOpen()                  (NET0 &= (~SDIO_MSK))
#define PWR_SFT1Select(Sel)             (NET0 = ((NET0 & (~SFT1_MSK)) | Sel))
//#define ADC_SDIOShort()                 (NET0 |= SDIO_SHORT)
//#define ADC_SDIOOpen()                  (NET0 &= (~SDIO_MSK))
//#define ADC_SFT1Select(Sel)             (NET0 = ((NET0 & (~SFT1_MSK)) | Sel))

#define PWR_CNTIStatus()             (NET3 & 0x01)
#define PWR_CNTIMFCOEnable() (NET3 |= SCMPO_MFCO)      
           
/*-------------------------------------------------------------------------------------------------|
|  Function call:                                                                                  |
|    For general and functional register access.                                                   |
|-------------------------------------------------------------------------------------------------*/
void PWR_VDDAOpen(unsigned char vdda);  //VDDA regulated selector

