/**************************************************************************************************|
|* Copyright 2020 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17p60bsfr.h>
#include <TMR.h>
#include <CLK.h>
#include <INT.h>


/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/
/*-------------------------------------------------------------------------------------------------|
|  Function: TMA_Open                                                                              |
|                                                                                                  |
|  Parameters:                                                                                     |
|         ck        - [in] TMAS1_DMSCK / TMAS1_LPCCK                                   |
|         cks       - [in] DTMA1_TMA1CKDIV2    / DTMA1_TMA1CKDIV4                                   |
|                          DTMA1_TMA1CKDIV8   / DTMA1_TMA1CKDIV16                                  |
|                          DTMA1_TMA1CKDIV32   / DTMA1_TMA1CKDIV64                                  |
|                          DTMA1_TMA1CKDIV128   / DTMA1_TMA1CKDIV256                                  |
|          cmp        - [in] 0x0~0xFF                                   |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the Timer-A1(TMA1)                                       |
|-------------------------------------------------------------------------------------------------*/
void TMA1_Open(unsigned char ck,    //TMA clock source
              unsigned char cks,                 //Pre-scale controller of TMA counting frequency
              unsigned char cmp)               //setting TMA1 comparison point
{
	TMA1_CLKSelect(ck);
	TMA1_CLKDiv(cks);
	TMA1_ClearTMA1();
	TMA1_CompSet(cmp);

	TA1IF_ClearFlag();
	TA1IE_Enable();
    if(cmp != 0)
    {
        TA1CIF_ClearFlag();
	    TA1CIE_Enable();
	}

}

/*-------------------------------------------------------------------------------------------------|
|  Function: TMB_Open                                                                              |
|                                                                                                  |
|  Parameters:                                                                                     |
|         ck        - [in] TMBS_LPCCK / TMBS_HSCK                                   |
|         cks       - [in] DTMB_TMBCKDIV8    / DTMB_TMBCKDIV4                                  |
|                          DTMB_TMBCKDIV2   / DTMB_TMBCKDIV1                                  |
|         mode       - [in] TB1M_16bit / TB1M_17bit / TB1M_2_8bit / TB1M_8_8bit                              |
|         trig_ctrl        - [in] TB1RT_LogicH / TB1RT_CP11                                   |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the Timer-B(TMB)                                           |
|-------------------------------------------------------------------------------------------------*/
void TMB_Open(unsigned char ck,             //TMB clock source
						  unsigned char cks,             //Pre-scale controller of TMB counting frequency
						  unsigned char mode,         //TMB operation mode
						  unsigned char trig_ctrl)    //TMB trigger controller
{
	CLK_TMBCKDivSelect(cks);
	CLK_TMBCKSelect(ck);
	TB1_ModeSelect(mode);
	TB1_Trig_Control(trig_ctrl);
	
	TB1IF_ClearFlag();
	TB1IE_Enable();
}

void TB1C0Set(unsigned int TMB)
{
	TB1C0H=(TMB>>8);
	TB1C0L= (0x00FF & TMB);
}

void TB1C1Set(unsigned int TMB)
{
	TB1C1H=(TMB>>8);
	TB1C1L= (0x00FF & TMB);
}

void TB1C2Set(unsigned int TMB)
{
	TB1C2H=(TMB>>8);
	TB1C2L= (0x00FF & TMB);
}